diff --git a/.changeset/big-roses-stare.md b/.changeset/big-roses-stare.md
new file mode 100644
index 0000000000..442e53522e
--- /dev/null
+++ b/.changeset/big-roses-stare.md
@@ -0,0 +1,5 @@
+---
+'@backstage/plugin-catalog-backend-module-msgraph': patch
+---
+
+export the function to read ms graph provider config
diff --git a/.changeset/breezy-dogs-serve.md b/.changeset/breezy-dogs-serve.md
new file mode 100644
index 0000000000..a92e5cdb0c
--- /dev/null
+++ b/.changeset/breezy-dogs-serve.md
@@ -0,0 +1,5 @@
+---
+'@backstage/create-app': patch
+---
+
+Cleaned up cases where deprecated code was being used but had a new location they should be imported from
diff --git a/.changeset/brown-poets-join.md b/.changeset/brown-poets-join.md
new file mode 100644
index 0000000000..bc6ccbaa70
--- /dev/null
+++ b/.changeset/brown-poets-join.md
@@ -0,0 +1,17 @@
+---
+'@backstage/create-app': patch
+---
+
+`knex` has been bumped to major version 3 and `better-sqlite3` to major version 9, which deprecate node 16 support.
+
+You can do the same in your own Backstage repository to ensure that you get future node 18+ relevant updates, by having the following lines in your `packages/backend/package.json`:
+
+```
+"dependencies": {
+ // ...
+ "knex": "^3.0.0"
+},
+"devDependencies": {
+ // ...
+ "better-sqlite3": "^9.0.0",
+```
diff --git a/.changeset/chatty-countries-refuse.md b/.changeset/chatty-countries-refuse.md
new file mode 100644
index 0000000000..d29d1a453b
--- /dev/null
+++ b/.changeset/chatty-countries-refuse.md
@@ -0,0 +1,5 @@
+---
+'@backstage/plugin-bazaar': patch
+---
+
+Updated Readme document in bazaar plugin
diff --git a/.changeset/curvy-carpets-kneel.md b/.changeset/curvy-carpets-kneel.md
new file mode 100644
index 0000000000..e6b0019edb
--- /dev/null
+++ b/.changeset/curvy-carpets-kneel.md
@@ -0,0 +1,5 @@
+---
+'@backstage/plugin-shortcuts': patch
+---
+
+Ensure that shortcuts aren't duplicate-checked against themselves
diff --git a/.changeset/famous-plums-sit.md b/.changeset/famous-plums-sit.md
new file mode 100644
index 0000000000..b85e26b87e
--- /dev/null
+++ b/.changeset/famous-plums-sit.md
@@ -0,0 +1,6 @@
+---
+'@backstage/core-components': patch
+'@backstage/plugin-catalog': patch
+---
+
+Fix spacing inconsistency with links and labels in headers
diff --git a/.changeset/healthy-dancers-dream.md b/.changeset/healthy-dancers-dream.md
new file mode 100644
index 0000000000..6a9869f03a
--- /dev/null
+++ b/.changeset/healthy-dancers-dream.md
@@ -0,0 +1,5 @@
+---
+'@backstage/frontend-app-api': patch
+---
+
+The options parameter of `createApp` is now optional.
diff --git a/.changeset/mighty-humans-shave.md b/.changeset/mighty-humans-shave.md
new file mode 100644
index 0000000000..7a4971e021
--- /dev/null
+++ b/.changeset/mighty-humans-shave.md
@@ -0,0 +1,5 @@
+---
+'@backstage/plugin-search-backend-module-elasticsearch': patch
+---
+
+Support AWS OpenSearch Serverless search backend. Does not support `_refresh` endpoint.
diff --git a/.changeset/olive-doors-begin.md b/.changeset/olive-doors-begin.md
new file mode 100644
index 0000000000..5d8978964c
--- /dev/null
+++ b/.changeset/olive-doors-begin.md
@@ -0,0 +1,24 @@
+---
+'@backstage/plugin-catalog-backend-module-incremental-ingestion': patch
+'@backstage/plugin-catalog-backend-module-unprocessed': patch
+'@backstage/plugin-search-backend-module-pg': patch
+'@backstage/plugin-entity-feedback-backend': patch
+'@backstage/plugin-code-coverage-backend': patch
+'@backstage/plugin-tech-insights-backend': patch
+'@backstage/plugin-user-settings-backend': patch
+'@backstage/backend-plugin-api': patch
+'@backstage/backend-test-utils': patch
+'@backstage/plugin-scaffolder-backend': patch
+'@backstage/plugin-linguist-backend': patch
+'@backstage/plugin-playlist-backend': patch
+'@backstage/plugin-techdocs-backend': patch
+'@backstage/backend-common': patch
+'@backstage/plugin-catalog-backend': patch
+'@backstage/backend-tasks': patch
+'@backstage/plugin-badges-backend': patch
+'@backstage/plugin-bazaar-backend': patch
+'@backstage/plugin-auth-backend': patch
+'@backstage/plugin-app-backend': patch
+---
+
+`knex` has been bumped to major version 3 and `better-sqlite3` to major version 9, which deprecate node 16 support.
diff --git a/.changeset/orange-jokes-tap.md b/.changeset/orange-jokes-tap.md
new file mode 100644
index 0000000000..0fd9e14a46
--- /dev/null
+++ b/.changeset/orange-jokes-tap.md
@@ -0,0 +1,5 @@
+---
+'@backstage/frontend-app-api': patch
+---
+
+Implement new `AppTreeApi`
diff --git a/.changeset/pretty-bats-end.md b/.changeset/pretty-bats-end.md
new file mode 100644
index 0000000000..8b08c5b00f
--- /dev/null
+++ b/.changeset/pretty-bats-end.md
@@ -0,0 +1,5 @@
+---
+'@backstage/plugin-catalog-backend-module-gitlab': patch
+---
+
+Resolved a bug affecting the retrieval of users from group members. By appending '/all' to the API call, we now include members from all inherited groups, as per Gitlab's API specifications. This change is reflected in the listSaaSUsers function.
diff --git a/.changeset/selfish-flies-kneel.md b/.changeset/selfish-flies-kneel.md
new file mode 100644
index 0000000000..0f13f11d11
--- /dev/null
+++ b/.changeset/selfish-flies-kneel.md
@@ -0,0 +1,5 @@
+---
+'@backstage/frontend-app-api': patch
+---
+
+No longer throw error on invalid input if the child is disabled.
diff --git a/.changeset/shiny-goats-flash.md b/.changeset/shiny-goats-flash.md
new file mode 100644
index 0000000000..35a7ce0697
--- /dev/null
+++ b/.changeset/shiny-goats-flash.md
@@ -0,0 +1,5 @@
+---
+'@backstage/frontend-plugin-api': patch
+---
+
+Add new `AppTreeApi`.
diff --git a/.changeset/strange-taxis-explode.md b/.changeset/strange-taxis-explode.md
new file mode 100644
index 0000000000..41bcf1895c
--- /dev/null
+++ b/.changeset/strange-taxis-explode.md
@@ -0,0 +1,6 @@
+---
+'@backstage/plugin-kubernetes-backend': patch
+'@backstage/plugin-kubernetes-common': patch
+---
+
+Fixed the lack of `resourcequotas` as part of the Default Objects to fetch from the kubernetes api
diff --git a/.changeset/thick-boats-decide.md b/.changeset/thick-boats-decide.md
new file mode 100644
index 0000000000..e258962ecd
--- /dev/null
+++ b/.changeset/thick-boats-decide.md
@@ -0,0 +1,5 @@
+---
+'@backstage/create-app': patch
+---
+
+Added missing node-gyp dependency to fix Docker image build
diff --git a/.changeset/violet-falcons-leave.md b/.changeset/violet-falcons-leave.md
new file mode 100644
index 0000000000..03b91957b1
--- /dev/null
+++ b/.changeset/violet-falcons-leave.md
@@ -0,0 +1,5 @@
+---
+'@backstage/plugin-catalog-react': patch
+---
+
+Removed unnecessary `@backstage/integration` dependency, replaced by `@backstage/integration-react`.
diff --git a/.github/ISSUE_TEMPLATE/config.yml b/.github/ISSUE_TEMPLATE/config.yml
index e4b99b3be1..a3ef40c13d 100644
--- a/.github/ISSUE_TEMPLATE/config.yml
+++ b/.github/ISSUE_TEMPLATE/config.yml
@@ -1,11 +1,8 @@
---
blank_issues_enabled: false
contact_links:
- - about: 'Please ask and answer usage questions in GitHub Discussions'
- name: Question
- url: 'https://github.com/backstage/backstage/discussions'
- - about: 'Alternatively, you can use the Backstage Community Discord'
- name: Chat
+ - about: 'Use the Backstage Community Discord for questions & discussions'
+ name: Questions
url: 'https://discord.gg/backstage-687207715902193673'
- about: 'Please check the FAQ before filing new issues'
name: 'Backstage FAQ'
diff --git a/.github/vale/Vocab/Backstage/accept.txt b/.github/vale/Vocab/Backstage/accept.txt
index 49dd7007ba..73f6d56bb4 100644
--- a/.github/vale/Vocab/Backstage/accept.txt
+++ b/.github/vale/Vocab/Backstage/accept.txt
@@ -107,6 +107,7 @@ dynatrace
Dynatrace
ecco
elasticsearch
+Entra
env
Env
esbuild
@@ -196,10 +197,12 @@ Leasot
lerna
Lerna
lightbox
+Lightsail
limitranges
LocalStack
lockdown
lockfile
+lookbehind
lunr
Luxon
magiclink
@@ -285,6 +288,7 @@ Podman
posix
postgres
postpack
+PR
pre
prebaked
preconfigured
@@ -292,11 +296,12 @@ prepack
Preprarer
productional
Protobuf
-proxying
proxied
+proxying
Proxying
pseudonymized
pubsub
+Pulumi
pygments
pymdownx
rankdir
@@ -304,6 +309,7 @@ readme
Readme
readonly
rebase
+rebasing
Recharts
Redash
replicasets
@@ -312,6 +318,7 @@ Repo
repos
rerender
rerenders
+resourcequotas
reusability
Reusability
roadmaps
@@ -425,8 +432,8 @@ unregistration
untracked
upsert
upvote
-url
URIs
+url
URLs
utils
Valentina
@@ -455,9 +462,3 @@ zod
Zolotusky
zoomable
zsh
-Pulumi
-Lightsail
-PR
-rebasing
-lookbehind
-Entra
\ No newline at end of file
diff --git a/.github/workflows/scorecard.yml b/.github/workflows/scorecard.yml
index 3b017e759c..f3dc873075 100644
--- a/.github/workflows/scorecard.yml
+++ b/.github/workflows/scorecard.yml
@@ -39,7 +39,7 @@ jobs:
persist-credentials: false
- name: 'Run analysis'
- uses: ossf/scorecard-action@483ef80eb98fb506c348f7d62e28055e49fe2398 # v2.3.0
+ uses: ossf/scorecard-action@0864cf19026789058feabb7e87baa5f140aac736 # v2.3.1
with:
results_file: results.sarif
results_format: sarif
@@ -66,6 +66,6 @@ jobs:
# Upload the results to GitHub's code scanning dashboard.
- name: 'Upload to code-scanning'
- uses: github/codeql-action/upload-sarif@49abf0ba24d0b7953cb586944e918a0b92074c80 # v2.22.4
+ uses: github/codeql-action/upload-sarif@74483a38d39275f33fcff5f35b679b5ca4a26a99 # v2.22.5
with:
sarif_file: results.sarif
diff --git a/.github/workflows/sync_snyk-monitor.yml b/.github/workflows/sync_snyk-monitor.yml
index 9268fc4975..eda19a3a88 100644
--- a/.github/workflows/sync_snyk-monitor.yml
+++ b/.github/workflows/sync_snyk-monitor.yml
@@ -58,6 +58,6 @@ jobs:
SNYK_TOKEN: ${{ secrets.SNYK_TOKEN }}
NODE_OPTIONS: --max-old-space-size=7168
- name: Upload Snyk report
- uses: github/codeql-action/upload-sarif@v2.22.4
+ uses: github/codeql-action/upload-sarif@v2.22.5
with:
sarif_file: snyk.sarif
diff --git a/.github/workflows/verify_codeql.yml b/.github/workflows/verify_codeql.yml
index 59aa41ff55..06feec23ae 100644
--- a/.github/workflows/verify_codeql.yml
+++ b/.github/workflows/verify_codeql.yml
@@ -55,7 +55,7 @@ jobs:
# Initializes the CodeQL tools for scanning.
- name: Initialize CodeQL
- uses: github/codeql-action/init@v2.22.4
+ uses: github/codeql-action/init@v2.22.5
with:
languages: ${{ matrix.language }}
# If you wish to specify custom queries, you can do so here or in a config file.
@@ -66,7 +66,7 @@ jobs:
# Autobuild attempts to build any compiled languages (C/C++, C#, or Java).
# If this step fails, then you should remove it and run the build manually (see below)
- name: Autobuild
- uses: github/codeql-action/autobuild@v2.22.4
+ uses: github/codeql-action/autobuild@v2.22.5
# âšī¸ Command-line programs to run using the OS shell.
# đ https://git.io/JvXDl
@@ -80,4 +80,4 @@ jobs:
# make release
- name: Perform CodeQL Analysis
- uses: github/codeql-action/analyze@v2.22.4
+ uses: github/codeql-action/analyze@v2.22.5
diff --git a/.github/workflows/verify_storybook.yml b/.github/workflows/verify_storybook.yml
index c428375a40..4afdefb17b 100644
--- a/.github/workflows/verify_storybook.yml
+++ b/.github/workflows/verify_storybook.yml
@@ -51,7 +51,7 @@ jobs:
- run: yarn build-storybook
- - uses: chromaui/action@c7e9d129ad2b8e728e10522270e14596473a7958 # v1
+ - uses: chromaui/action@d726e4e790a99e876f71b8e09d3053bfe783d6b8 # v1
with:
token: ${{ secrets.GITHUB_TOKEN }}
# projectToken intentionally shared to allow collaborators to run Chromatic on forks
diff --git a/docs/assets/frontend-system/architecture-app.drawio.svg b/docs/assets/frontend-system/architecture-app.drawio.svg
new file mode 100644
index 0000000000..ed414dde97
--- /dev/null
+++ b/docs/assets/frontend-system/architecture-app.drawio.svg
@@ -0,0 +1,125 @@
+
diff --git a/docs/assets/frontend-system/architecture-building-blocks.drawio.svg b/docs/assets/frontend-system/architecture-building-blocks.drawio.svg
new file mode 100644
index 0000000000..5be95e354d
--- /dev/null
+++ b/docs/assets/frontend-system/architecture-building-blocks.drawio.svg
@@ -0,0 +1,331 @@
+
diff --git a/docs/assets/frontend-system/architecture-extension.drawio.svg b/docs/assets/frontend-system/architecture-extension.drawio.svg
new file mode 100644
index 0000000000..d7bbf43ad0
--- /dev/null
+++ b/docs/assets/frontend-system/architecture-extension.drawio.svg
@@ -0,0 +1,332 @@
+
diff --git a/docs/deployment/docker.md b/docs/deployment/docker.md
index 4b29ef8a0e..c9ace49d4d 100644
--- a/docs/deployment/docker.md
+++ b/docs/deployment/docker.md
@@ -194,8 +194,6 @@ WORKDIR /app
COPY --from=packages --chown=node:node /app .
-# Stop cypress from downloading it's massive binary.
-ENV CYPRESS_INSTALL_BINARY=0
RUN --mount=type=cache,target=/home/node/.cache/yarn,sharing=locked,uid=1000,gid=1000 \
yarn install --frozen-lockfile --network-timeout 600000
diff --git a/docs/features/kubernetes/configuration.md b/docs/features/kubernetes/configuration.md
index b31c69eac1..07e3a8a828 100644
--- a/docs/features/kubernetes/configuration.md
+++ b/docs/features/kubernetes/configuration.md
@@ -452,6 +452,7 @@ Overrides for the Kubernetes object types fetched from the cluster. The default
- services
- configmaps
- limitranges
+- resourcequotas
- deployments
- replicasets
- horizontalpodautoscalers
@@ -504,6 +505,7 @@ rules:
- ingresses
- statefulsets
- limitranges
+ - resourcequotas
- daemonsets
verbs:
- get
diff --git a/docs/frontend-system/architecture/01-index.md b/docs/frontend-system/architecture/01-index.md
new file mode 100644
index 0000000000..380ebaa335
--- /dev/null
+++ b/docs/frontend-system/architecture/01-index.md
@@ -0,0 +1,51 @@
+---
+id: index
+title: Frontend System Architecture
+sidebar_label: Overview
+# prettier-ignore
+description: The structure and architecture of the new Frontend System
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
+
+## Building Blocks
+
+This section introduces the high-level building blocks upon which this new
+system is built. Most of these concepts exist in our current system too, although
+in some cases you need to squint quite a lot to see the similarity.
+
+Regardless of whether you are setting up your own backstage instance,
+developing plugins, or extending plugins with new features, it is
+important to understand these concepts.
+
+The diagram below provides an overview of the different building blocks, and the other blocks that each of them interact with.
+
+
+
+### App
+
+This is the app instance itself that you create and use as the root of your Backstage frontend application. It does not have any direct functionality in and of itself, but is simply responsible for wiring things together.
+
+### Extensions
+
+Extensions are the building blocks that build out both the visual and non-visual structure of the application. There are both built-in extensions provided by the app itself, as well as extensions provided by plugins. Each extension is attached to a parent with which it shares data, and can have any number of children of its own. It is up to the app to wire together all extensions into a single tree known as the app extension tree. It is from this structure that the entire app can then be instantiated and rendered.
+
+### Plugins
+
+Plugins provide the actual features inside an app. The size of a plugin can range from a tiny component to an entire new system in which other plugins can be composed and integrated. Plugins can be completely standalone, or build on top of each other to extend existing plugins and augment their features. Plugins can communicate with each other by composing their extensions, or by sharing Utility APIs and routes.
+
+### Extension Overrides
+
+In addition to the built-in extensions and extensions provided by plugins, it is also possible to install extension overrides. This is a collection of extensions with high priority that can replace existing extensions. They can for example be used to override an individual extension provided by a plugin, or install a completely new extension, such as a new app theme.
+
+### Utility APIs
+
+Utility APIs provide functionality that makes it easier to build plugins, make it possible for plugins to share functionality with other plugins, as well as serve as a customization point for integrators to change the behavior of the app. Each Utility API is defined by a TypeScript interface as well as a reference used to access the implementations. The implementations of Utility APIs are defined by extensions that are provided and can be overridden the same as any other extension.
+
+### Routes
+
+The Backstage routing system adds a layer of indirection that makes it possible for plugins to route to each other's extensions without explicit knowledge of what URL paths the extension are rendered at or if they even exist at all. It makes it possible for plugins to share routes with each other and dynamically generate concrete links at runtime. It is the responsibility of the app to resolve these links to actual URLs, but it is also possible for integrators to define their own route bindings that decide how the links should be resolved. The routing system also lets plugins define internal routes, aiding in the linking to different content in the same plugin.
+
+## Package structure
+
+TODO
diff --git a/docs/frontend-system/architecture/02-app.md b/docs/frontend-system/architecture/02-app.md
new file mode 100644
index 0000000000..52fd20faee
--- /dev/null
+++ b/docs/frontend-system/architecture/02-app.md
@@ -0,0 +1,48 @@
+---
+id: apps
+title: App Instances
+sidebar_label: App
+# prettier-ignore
+description: App instances
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
+
+## The App Instance
+
+The app instance is main entry point for creating a frontend app. It doesn't do much on its own, but is instead responsible for wiring things together that have been provided as features from other parts of the system.
+
+Below is a simple example of how to create and render an app instance:
+
+```ts
+import ReactDOM from 'react-dom/client';
+import { createApp } from '@backstage/frontend-app-api';
+
+// Create your app instance
+const app = createApp({
+ // Features such as plugins can be installed explicitly, but we will explore other options later on
+ features: [catalogPlugin],
+});
+
+// This creates a React element that renders the entire app
+const root = app.createRoot();
+
+// Just like any other React we need a root element. No server side rendering is used.
+const rootEl = document.getElementById('root')!;
+
+ReactDOM.createRoot(rootEl).render(app);
+```
+
+We call `createApp` to create a new app instance, which is responsible for wiring together all of the features that we provide to the app. It also provides a set of built-in [Extensions](./03-extensions.md) that help build out the foundations of the app, as well as defaults for many other systems such as [Utility API](./06-utility-apis.md) implementations, components, icons, themes, and how to load configuration. No real work is done at the point of creating the app though, it's all deferred to the rendering of the element returned from `app.createRoot()`.
+
+It is possible to explicitly install features when creating the app, although typically these will instead be discovered automatically which we'll explore later on. Nevertheless these features are what build out the actual functionality of the app by providing [Extensions](./03-extensions.md). These extensions are wired together by the app into a tree structure known as the app extension tree. Each node in this tree receives data from its child nodes, and pass along data to its parent. The following diagram illustrates the shape of a small app extension tree.
+
+
+
+Each node in this tree is an extension with a parent node and children. The colored shapes represent extension data inputs and output, where each color is one unique type of data. You can see that there are both extensions that output data that is ignored by the parent, as well as extensions that accept inputs but do not have any children. There are a couple of different tools at your disposal when creating and extension that lets you define different requirements for your inputs and output, which we will cover in greater details in the [Extensions](./03-extensions.md) section.
+
+A common type of data that is shared between extensions is React elements and components. These can in turn be rendered by each other in their own React components, which ends up forming a parallel tree of React components that is similar in shape to that of the app extension tree. At the top of the app extension tree is a built-in root extension that among other things outputs a React element. This element also ends up being the root of the parallel React tree, and is rendered by the React element returned by `app.createRoot()`.
+
+## Feature Discovery
+
+TODO
diff --git a/docs/frontend-system/architecture/03-extensions.md b/docs/frontend-system/architecture/03-extensions.md
new file mode 100644
index 0000000000..3d08bf1721
--- /dev/null
+++ b/docs/frontend-system/architecture/03-extensions.md
@@ -0,0 +1,104 @@
+---
+id: extensions
+title: Frontend Extensions
+sidebar_label: Extensions
+# prettier-ignore
+description: Frontend extensions
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
+
+As mentioned in the [previous section](./02-app.md), Backstage apps are built up from a tree of extensions. This section will go into more detail about what extensions are, how to create and use them, and how to create your own extensibility patterns.
+
+## Extension Structure
+
+Each extensions has a number of different properties that define how it behaves and how it interacts with other extensions and the rest of the app. Some of these properties are fixed, while others can be customized by integrators. The diagram below illustrates the structure of an extension.
+
+
+
+### ID
+
+The ID of an extension is used to uniquely identity it, and it should ideally by unique across the entire Backstage ecosystem. For each frontend app instance there can only be a single extension for any given ID. Installing multiple extensions with the same ID will either result in an error or one of the extensions will override the others. The ID is also used to reference the extensions from other extensions, in configuration, and in other places such as developer tools and analytics.
+
+### Output
+
+The output of an extension is the data that it provides to its parent extension, and ultimately its contribution to the app. The output itself comes in the form of a collection of arbitrary values, anything that can be represented as a TypeScript type. However, each individual output value must be associated with a shared reference known as an extension data reference. You must also use these same references to be able to access individual output values of an extension.
+
+### Inputs
+
+The inputs of an extension define the data that it received from its children. Each extension can have multiple different inputs identified by an input name. These inputs each have their own set of data that they expect, which is defined as a collection of extension data references. An extension will only have access to the data that it has explicitly requested from each input.
+
+### Attachment Point
+
+The attachment point of an extension decides where in the app extension tree it will be located. It is defined by the ID of the parent extension, as well as the name of the input to attach to. Through the attachment point the extension will share its own output as inputs to the parent extension. An extension can only be attached to an input that matches its own output, it is an error to try to attach an extension to an input the requires data that the extension does not provide in its output.
+
+The attachment point is one of the configurable properties of an extension, and can be overridden by integrators. In doing so, care must be taken to make sure that one doesn't attach an extension to an incompatible input. Extensions can also only be attached to a single input and parent at a time. This means that the app extension tree can not contain any cycles, as the extension ancestry will either be terminated at the root, or be detached from it.
+
+### Disabled
+
+Each extension in the app can be disabled, meaning it will not be instantiated and its parent will effectively not see it in its inputs. When creating an extension you can also specify whether extensions should be disabled by default. This makes it possible to for example install multiple extensions in an app, but only choose to enable one or a few of them depending on the environment.
+
+The ordering of extensions is sometimes very important, as it may for example affect in which order they show up in the UI. When an extension is toggled from disabled to enabled through configuration it resets the ordering of the extension, pushing it to the end of the list. It is generally recommended to leave extensions as disabled by default if their order is important, allowing for the order in which their are enabled in the configuration to determine their order in the app.
+
+### Configuration & Configuration Schema
+
+Each extension can define a configuration schema that describes the configuration that it accepts. This schema is used to validate the configuration provided by integrators, but also to fill in default configuration values. The configuration itself is provided by integrators in order to customize the extension. It is not possible to provide a default configuration of an extension, this must instead be done through defaults in the configuration schema. This allows for a simpler configuration logic where multiple configurations of the same extension completely replace each other rather than being merged.
+
+### Factory
+
+The extension factory is the implementation of the extension itself. It is a function that is provided with any inputs and configuration that the extension received, and must produce the output that it defined. When an app instance starts up it will call the factory function of each extension that is part of the app, starting at leaf nodes and working its way up to the root of the app extension tree. The factory will only be called for active extensions, which is an extension that is not disabled and has an active parent.
+
+Extension factories should be lean and not do any heavy lifting or async work, as they are called during the initialization of the app. For example, if you need to do an expensive computation to generate your output, then prefer outputting a callback that does the computation instead. This allows the parent extension to defer the computation for later so that you avoid blocking the app startup.
+
+## Creating an Extensions
+
+Extensions are created using the `createExtension` function from `@backstage/frontend-plugin-api`. At minimum you need to provide an ID, attachment point, output definition, and a factory function. The following example shows the creation of a minimal extension:
+
+```tsx
+const extension = createExtension({
+ id: 'my-extension',
+ // This is the attachment point, `id` is the ID of the parent extension,
+ // while `input` is the name of the input to attach to.
+ attachTo: { id: 'my-parent', input: 'content' },
+ // The output map defines the outputs of the extension. The object keys
+ // are only used internally to map the outputs of the factory and do
+ // not need to match the keys of the input.
+ output: {
+ element: coreExtensionData.reactElement,
+ },
+ // This factory is called to instantiate the extensions and produce its output.
+ factory({ bind }) {
+ bind({
+ element:
Hello World
,
+ });
+ },
+});
+```
+
+Note that while the `createExtension` is public API and used in many places, it is not typically what you use when building plugins and features. Instead there are many extension creator functions exported by both the core APIs and plugins that make it easier to create extensions for more specific usages.
+
+... TODO ...
+
+## Extension Data
+
+TODO
+
+## Extension Inputs
+
+TODO
+
+## Configuration
+
+TODO
+
+## Configuration Schema
+
+TODO
+
+## Extension Creators
+
+TODO
+
+## Extension Boundary
+
+TODO
diff --git a/docs/frontend-system/architecture/04-plugins.md b/docs/frontend-system/architecture/04-plugins.md
new file mode 100644
index 0000000000..a1e85f8407
--- /dev/null
+++ b/docs/frontend-system/architecture/04-plugins.md
@@ -0,0 +1,9 @@
+---
+id: plugins
+title: Frontend Plugins
+sidebar_label: Plugins
+# prettier-ignore
+description: Frontend plugins
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
diff --git a/docs/frontend-system/architecture/05-extension-overrides.md b/docs/frontend-system/architecture/05-extension-overrides.md
new file mode 100644
index 0000000000..743a5ea59e
--- /dev/null
+++ b/docs/frontend-system/architecture/05-extension-overrides.md
@@ -0,0 +1,9 @@
+---
+id: extension overrides
+title: Frontend Extension Overrides
+sidebar_label: Extension Overrides
+# prettier-ignore
+description: Frontend extension overrides
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
diff --git a/docs/frontend-system/architecture/06-utility-apis.md b/docs/frontend-system/architecture/06-utility-apis.md
new file mode 100644
index 0000000000..135f60744a
--- /dev/null
+++ b/docs/frontend-system/architecture/06-utility-apis.md
@@ -0,0 +1,11 @@
+---
+id: utility-apis
+title: Utility APIs
+sidebar_label: Utility APIs
+# prettier-ignore
+description: Utility APIs
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
+
+See [Utility APIs docs](../../api/utility-apis.md).
diff --git a/docs/frontend-system/architecture/07-routes.md b/docs/frontend-system/architecture/07-routes.md
new file mode 100644
index 0000000000..354eaeda13
--- /dev/null
+++ b/docs/frontend-system/architecture/07-routes.md
@@ -0,0 +1,11 @@
+---
+id: routes
+title: Frontend Routes
+sidebar_label: Routes
+# prettier-ignore
+description: Frontend routes
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
+
+See [routing system docs](../../plugins/composability.md#routing-system)
diff --git a/docs/frontend-system/index.md b/docs/frontend-system/index.md
new file mode 100644
index 0000000000..3970c09f00
--- /dev/null
+++ b/docs/frontend-system/index.md
@@ -0,0 +1,15 @@
+---
+id: index
+title: The Frontend System
+sidebar_label: Introduction
+# prettier-ignore
+description: The Frontend System
+---
+
+> **NOTE: The new frontend system is in a highly experimental phase**
+
+## Status
+
+The new frontend system is in an experimental phase and we do not recommend any plugins or apps to migrate.
+
+You can find an example app setup in [the `app-next` package](https://github.com/backstage/backstage/tree/master/packages/app-next).
diff --git a/docs/integrations/azure/org.md b/docs/integrations/azure/org.md
index 370678d9f9..c4968b0399 100644
--- a/docs/integrations/azure/org.md
+++ b/docs/integrations/azure/org.md
@@ -1,6 +1,6 @@
---
id: org
-title: Microsoft Entra tenantal Data
+title: Microsoft Entra Tenant Data
sidebar_label: Org Data
# prettier-ignore
description: Importing users and groups from Microsoft Entra ID into Backstage
diff --git a/microsite/data/plugins/nexus-repository-manager.yaml b/microsite/data/plugins/nexus-repository-manager.yaml
new file mode 100644
index 0000000000..aca1e366e2
--- /dev/null
+++ b/microsite/data/plugins/nexus-repository-manager.yaml
@@ -0,0 +1,10 @@
+---
+title: Nexus Repository Manager
+author: Red Hat
+authorUrl: https://redhat.com
+category: Image
+description: View information about the build artifacts in your Nexus Repository Manager in Backstage.
+documentation: https://janus-idp.io/plugins/nexus-repository-manager
+iconUrl: https://janus-idp.io/images/plugins/nexus-repository-manager.svg
+npmPackageName: '@janus-idp/backstage-plugin-nexus-repository-manager'
+addedDate: '2023-10-25'
diff --git a/microsite/yarn.lock b/microsite/yarn.lock
index 0200b84675..7b3a8d5cdc 100644
--- a/microsite/yarn.lock
+++ b/microsite/yarn.lock
@@ -3265,9 +3265,9 @@ __metadata:
linkType: hard
"@types/webpack-env@npm:^1.18.0":
- version: 1.18.2
- resolution: "@types/webpack-env@npm:1.18.2"
- checksum: 883908ade827d35a10efc574fb6f2728a7c520d4296cf1507633ac7457204ccd697bc6c8cadac99bc5d96074a6109c658ebfde59f42ba5ba0fdfffc538892b0f
+ version: 1.18.3
+ resolution: "@types/webpack-env@npm:1.18.3"
+ checksum: f24e82485d8e325b1875608766ba6dad2b2f53a0fb182bc96173b4590110c6b791163402cdf19b50c04e8c05292f227a08aafe9230b2bba52c40c5f7ceccc101
languageName: node
linkType: hard
diff --git a/packages/backend-common/api-report.md b/packages/backend-common/api-report.md
index f4d430ccbd..4f1dcdbf81 100644
--- a/packages/backend-common/api-report.md
+++ b/packages/backend-common/api-report.md
@@ -32,6 +32,7 @@ import { HostDiscovery as HostDiscovery_2 } from '@backstage/backend-app-api';
import { IdentityService } from '@backstage/backend-plugin-api';
import { isChildPath } from '@backstage/cli-common';
import { Knex } from 'knex';
+import knexFactory from 'knex';
import { KubeConfig } from '@kubernetes/client-node';
import { LifecycleService } from '@backstage/backend-plugin-api';
import { LoadConfigOptionsRemote } from '@backstage/config-loader';
@@ -222,7 +223,7 @@ export function createDatabaseClient(
lifecycle: LifecycleService;
pluginMetadata: PluginMetadataService;
},
-): Knex;
+): knexFactory.Knex;
// @public
export function createRootLogger(
diff --git a/packages/backend-common/package.json b/packages/backend-common/package.json
index fad87cc3ec..f32f75291a 100644
--- a/packages/backend-common/package.json
+++ b/packages/backend-common/package.json
@@ -89,14 +89,14 @@
"isomorphic-git": "^1.23.0",
"jose": "^4.6.0",
"keyv": "^4.5.2",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"lodash": "^4.17.21",
"logform": "^2.3.2",
"luxon": "^3.0.0",
"minimatch": "^5.0.0",
"mysql2": "^2.2.5",
"node-fetch": "^2.6.7",
- "pg": "^8.3.0",
+ "pg": "^8.11.3",
"raw-body": "^2.4.1",
"tar": "^6.1.12",
"uuid": "^8.3.2",
@@ -129,7 +129,7 @@
"@types/webpack-env": "^1.15.2",
"@types/yauzl": "^2.10.0",
"aws-sdk-client-mock": "^2.0.0",
- "better-sqlite3": "^8.0.0",
+ "better-sqlite3": "^9.0.0",
"http-errors": "^2.0.0",
"msw": "^1.0.0",
"mysql2": "^2.2.5",
diff --git a/packages/backend-plugin-api/package.json b/packages/backend-plugin-api/package.json
index a1f9149098..c1c26b56df 100644
--- a/packages/backend-plugin-api/package.json
+++ b/packages/backend-plugin-api/package.json
@@ -52,7 +52,7 @@
"@backstage/types": "workspace:^",
"@types/express": "^4.17.6",
"express": "^4.17.1",
- "knex": "^2.0.0"
+ "knex": "^3.0.0"
},
"devDependencies": {
"@backstage/cli": "workspace:^"
diff --git a/packages/backend-tasks/package.json b/packages/backend-tasks/package.json
index f38a209831..37b3e925dd 100644
--- a/packages/backend-tasks/package.json
+++ b/packages/backend-tasks/package.json
@@ -39,7 +39,7 @@
"@opentelemetry/api": "^1.3.0",
"@types/luxon": "^3.0.0",
"cron": "^2.0.0",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"lodash": "^4.17.21",
"luxon": "^3.0.0",
"uuid": "^8.0.0",
diff --git a/packages/backend-test-utils/package.json b/packages/backend-test-utils/package.json
index 1216487880..e219a353ec 100644
--- a/packages/backend-test-utils/package.json
+++ b/packages/backend-test-utils/package.json
@@ -49,13 +49,13 @@
"@backstage/errors": "workspace:^",
"@backstage/plugin-auth-node": "workspace:^",
"@backstage/types": "workspace:^",
- "better-sqlite3": "^8.0.0",
+ "better-sqlite3": "^9.0.0",
"express": "^4.17.1",
"fs-extra": "^10.0.1",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"msw": "^1.0.0",
"mysql2": "^2.2.5",
- "pg": "^8.3.0",
+ "pg": "^8.11.3",
"testcontainers": "^8.1.2",
"textextensions": "^5.16.0",
"uuid": "^8.0.0"
diff --git a/packages/backend/package.json b/packages/backend/package.json
index bd28eadb8f..6b52cb8993 100644
--- a/packages/backend/package.json
+++ b/packages/backend/package.json
@@ -84,7 +84,7 @@
"@opentelemetry/exporter-prometheus": "^0.44.0",
"@opentelemetry/sdk-metrics": "^1.13.0",
"azure-devops-node-api": "^11.0.1",
- "better-sqlite3": "^8.0.0",
+ "better-sqlite3": "^9.0.0",
"dockerode": "^3.3.1",
"example-app": "link:../app",
"express": "^4.17.1",
@@ -92,7 +92,7 @@
"express-promise-router": "^4.1.0",
"luxon": "^3.0.0",
"mysql2": "^2.2.5",
- "pg": "^8.3.0",
+ "pg": "^8.11.3",
"pg-connection-string": "^2.3.0",
"prom-client": "^14.0.1",
"winston": "^3.2.1"
diff --git a/packages/core-app-api/src/apis/implementations/FetchApi/IdentityAuthInjectorFetchMiddleware.ts b/packages/core-app-api/src/apis/implementations/FetchApi/IdentityAuthInjectorFetchMiddleware.ts
index 810d9e76c1..6f9733cba1 100644
--- a/packages/core-app-api/src/apis/implementations/FetchApi/IdentityAuthInjectorFetchMiddleware.ts
+++ b/packages/core-app-api/src/apis/implementations/FetchApi/IdentityAuthInjectorFetchMiddleware.ts
@@ -55,8 +55,12 @@ export class IdentityAuthInjectorFetchMiddleware implements FetchMiddleware {
apply(next: typeof fetch): typeof fetch {
return async (input, init) => {
// Skip this middleware if the header already exists, or if the URL
- // doesn't match any of the allowlist items, or if there was no token
- const request = new Request(input, init);
+ // doesn't match any of the allowlist items, or if there was no token.
+ // NOTE(freben): The "as any" casts here and below are because of subtle
+ // undici type differences that happened in a node types bump. Those are
+ // immaterial to the code at hand at runtime, as the global fetch and
+ // Request are always taken from the same place.
+ const request = new Request(input as any, init);
const { token } = await this.identityApi.getCredentials();
if (
request.headers.get(this.headerName) ||
@@ -64,7 +68,7 @@ export class IdentityAuthInjectorFetchMiddleware implements FetchMiddleware {
!token ||
!this.allowUrl(request.url)
) {
- return next(input, init);
+ return next(input as any, init);
}
request.headers.set(this.headerName, this.headerValue(token));
diff --git a/packages/core-app-api/src/apis/implementations/FetchApi/PluginProtocolResolverFetchMiddleware.ts b/packages/core-app-api/src/apis/implementations/FetchApi/PluginProtocolResolverFetchMiddleware.ts
index ff20b594b4..e0afaed614 100644
--- a/packages/core-app-api/src/apis/implementations/FetchApi/PluginProtocolResolverFetchMiddleware.ts
+++ b/packages/core-app-api/src/apis/implementations/FetchApi/PluginProtocolResolverFetchMiddleware.ts
@@ -34,11 +34,15 @@ export class PluginProtocolResolverFetchMiddleware implements FetchMiddleware {
apply(next: typeof fetch): typeof fetch {
return async (input, init) => {
- const request = new Request(input, init);
+ // NOTE(freben): The "as any" casts here and below are because of subtle
+ // undici type differences that happened in a node types bump. Those are
+ // immaterial to the code at hand at runtime, as the global fetch and
+ // Request are always taken from the same place.
+ const request = new Request(input as any, init);
const prefix = 'plugin://';
if (!request.url.startsWith(prefix)) {
- return next(input, init);
+ return next(input as any, init);
}
// Switch to a known protocol, since browser URL parsing misbehaves wildly
@@ -57,7 +61,7 @@ export class PluginProtocolResolverFetchMiddleware implements FetchMiddleware {
const target = `${join(base, pathname)}${search}${hash}`;
return next(
target,
- typeof input === 'string' || isUrl(input) ? init : input,
+ typeof input === 'string' || isUrl(input) ? init : (input as any),
);
};
}
diff --git a/packages/core-components/src/layout/HeaderLabel/HeaderLabel.test.tsx b/packages/core-components/src/layout/HeaderLabel/HeaderLabel.test.tsx
index 3dff1f51be..7f863d57fa 100644
--- a/packages/core-components/src/layout/HeaderLabel/HeaderLabel.test.tsx
+++ b/packages/core-components/src/layout/HeaderLabel/HeaderLabel.test.tsx
@@ -51,4 +51,29 @@ describe('', () => {
expect(rendered.getByText('Value')).toBeInTheDocument();
expect(anchor.href).toBe('http://localhost/test');
});
+
+ it('should use a `p` tag if the provided value is a string', async () => {
+ const rendered = await renderInTestApp(
+ ,
+ );
+ expect(rendered.getByText('Value').tagName).toBe('P');
+ });
+
+ it('should use a `span` tag if the provided value is not a string', async () => {
+ const rendered = await renderInTestApp(
+ Value>} />,
+ );
+ expect(rendered.getByText('Value').tagName).toBe('SPAN');
+ });
+
+ it('should use the correct custom typography root component', async () => {
+ const rendered = await renderInTestApp(
+ ,
+ );
+ expect(rendered.container.querySelector('tr')).toBeInTheDocument();
+ });
});
diff --git a/packages/core-components/src/layout/HeaderLabel/HeaderLabel.tsx b/packages/core-components/src/layout/HeaderLabel/HeaderLabel.tsx
index e6ca9b720e..fdd48a5d81 100644
--- a/packages/core-components/src/layout/HeaderLabel/HeaderLabel.tsx
+++ b/packages/core-components/src/layout/HeaderLabel/HeaderLabel.tsx
@@ -49,12 +49,19 @@ const useStyles = makeStyles(
type HeaderLabelContentProps = PropsWithChildren<{
value: React.ReactNode;
className: string;
+ typographyRootComponent?: keyof JSX.IntrinsicElements;
}>;
-const HeaderLabelContent = ({ value, className }: HeaderLabelContentProps) => {
+const HeaderLabelContent = ({
+ value,
+ className,
+ typographyRootComponent,
+}: HeaderLabelContentProps) => {
return (
{value}
@@ -65,6 +72,7 @@ const HeaderLabelContent = ({ value, className }: HeaderLabelContentProps) => {
type HeaderLabelProps = {
label: string;
value?: HeaderLabelContentProps['value'];
+ contentTypograpyRootComponent?: HeaderLabelContentProps['typographyRootComponent'];
url?: string;
};
@@ -75,12 +83,13 @@ type HeaderLabelProps = {
*
*/
export function HeaderLabel(props: HeaderLabelProps) {
- const { label, value, url } = props;
+ const { label, value, url, contentTypograpyRootComponent } = props;
const classes = useStyles();
const content = (
'}
+ typographyRootComponent={contentTypograpyRootComponent}
/>
);
return (
diff --git a/packages/create-app/src/lib/tasks.test.ts b/packages/create-app/src/lib/tasks.test.ts
index c436bf5ad2..e7c406f51c 100644
--- a/packages/create-app/src/lib/tasks.test.ts
+++ b/packages/create-app/src/lib/tasks.test.ts
@@ -53,12 +53,15 @@ jest.mock('./versions', () => ({
'@backstage/plugin-auth-backend': '1.0.0',
'@backstage/plugin-auth-node': '1.0.0',
'@backstage/plugin-catalog-backend': '1.0.0',
+ '@backstage/plugin-catalog-backend-module-scaffolder-entity-model': '1.0.0',
'@backstage/plugin-permission-common': '1.0.0',
'@backstage/plugin-permission-node': '1.0.0',
'@backstage/plugin-proxy-backend': '1.0.0',
'@backstage/plugin-scaffolder-backend': '1.0.0',
'@backstage/plugin-search-backend': '1.0.0',
+ '@backstage/plugin-search-backend-module-catalog': '1.0.0',
'@backstage/plugin-search-backend-module-pg': '1.0.0',
+ '@backstage/plugin-search-backend-module-techdocs': '1.0.0',
'@backstage/plugin-search-backend-node': '1.0.0',
'@backstage/plugin-techdocs-backend': '1.0.0',
'@backstage/app-defaults': '1.0.0',
diff --git a/packages/create-app/src/lib/versions.ts b/packages/create-app/src/lib/versions.ts
index 67db8b4a78..81bae3c0b8 100644
--- a/packages/create-app/src/lib/versions.ts
+++ b/packages/create-app/src/lib/versions.ts
@@ -55,6 +55,7 @@ import { version as pluginCatalog } from '../../../../plugins/catalog/package.js
import { version as pluginCatalogCommon } from '../../../../plugins/catalog-common/package.json';
import { version as pluginCatalogReact } from '../../../../plugins/catalog-react/package.json';
import { version as pluginCatalogBackend } from '../../../../plugins/catalog-backend/package.json';
+import { version as pluginCatalogBackendModuleScaffolderEntityModel } from '../../../../plugins/catalog-backend-module-scaffolder-entity-model/package.json';
import { version as pluginCatalogGraph } from '../../../../plugins/catalog-graph/package.json';
import { version as pluginCatalogImport } from '../../../../plugins/catalog-import/package.json';
import { version as pluginCircleci } from '../../../../plugins/circleci/package.json';
@@ -72,7 +73,9 @@ import { version as pluginScaffolderBackend } from '../../../../plugins/scaffold
import { version as pluginSearch } from '../../../../plugins/search/package.json';
import { version as pluginSearchReact } from '../../../../plugins/search-react/package.json';
import { version as pluginSearchBackend } from '../../../../plugins/search-backend/package.json';
+import { version as pluginSearchBackendModuleCatalog } from '../../../../plugins/search-backend-module-catalog/package.json';
import { version as pluginSearchBackendModulePg } from '../../../../plugins/search-backend-module-pg/package.json';
+import { version as pluginSearchBackendModuleTechdocs } from '../../../../plugins/search-backend-module-techdocs/package.json';
import { version as pluginSearchBackendNode } from '../../../../plugins/search-backend-node/package.json';
import { version as pluginTechRadar } from '../../../../plugins/tech-radar/package.json';
import { version as pluginTechdocs } from '../../../../plugins/techdocs/package.json';
@@ -104,6 +107,8 @@ export const packageVersions = {
'@backstage/plugin-catalog-common': pluginCatalogCommon,
'@backstage/plugin-catalog-react': pluginCatalogReact,
'@backstage/plugin-catalog-backend': pluginCatalogBackend,
+ '@backstage/plugin-catalog-backend-module-scaffolder-entity-model':
+ pluginCatalogBackendModuleScaffolderEntityModel,
'@backstage/plugin-catalog-graph': pluginCatalogGraph,
'@backstage/plugin-catalog-import': pluginCatalogImport,
'@backstage/plugin-circleci': pluginCircleci,
@@ -121,7 +126,11 @@ export const packageVersions = {
'@backstage/plugin-search': pluginSearch,
'@backstage/plugin-search-react': pluginSearchReact,
'@backstage/plugin-search-backend': pluginSearchBackend,
+ '@backstage/plugin-search-backend-module-catalog':
+ pluginSearchBackendModuleCatalog,
'@backstage/plugin-search-backend-module-pg': pluginSearchBackendModulePg,
+ '@backstage/plugin-search-backend-module-techdocs':
+ pluginSearchBackendModuleTechdocs,
'@backstage/plugin-search-backend-node': pluginSearchBackendNode,
'@backstage/plugin-tech-radar': pluginTechRadar,
'@backstage/plugin-techdocs': pluginTechdocs,
diff --git a/packages/create-app/templates/default-app/packages/backend/package.json.hbs b/packages/create-app/templates/default-app/packages/backend/package.json.hbs
index cb358db911..f3ed808afe 100644
--- a/packages/create-app/templates/default-app/packages/backend/package.json.hbs
+++ b/packages/create-app/templates/default-app/packages/backend/package.json.hbs
@@ -25,20 +25,24 @@
"@backstage/plugin-auth-backend": "^{{version '@backstage/plugin-auth-backend'}}",
"@backstage/plugin-auth-node": "^{{version '@backstage/plugin-auth-node'}}",
"@backstage/plugin-catalog-backend": "^{{version '@backstage/plugin-catalog-backend'}}",
+ "@backstage/plugin-catalog-backend-module-scaffolder-entity-model": "^{{version '@backstage/plugin-catalog-backend-module-scaffolder-entity-model'}}",
"@backstage/plugin-permission-common": "^{{version '@backstage/plugin-permission-common'}}",
"@backstage/plugin-permission-node": "^{{version '@backstage/plugin-permission-node'}}",
"@backstage/plugin-proxy-backend": "^{{version '@backstage/plugin-proxy-backend'}}",
"@backstage/plugin-scaffolder-backend": "^{{version '@backstage/plugin-scaffolder-backend'}}",
"@backstage/plugin-search-backend": "^{{version '@backstage/plugin-search-backend'}}",
+ "@backstage/plugin-search-backend-module-catalog": "^{{version '@backstage/plugin-search-backend-module-catalog'}}",
"@backstage/plugin-search-backend-module-pg": "^{{version '@backstage/plugin-search-backend-module-pg'}}",
+ "@backstage/plugin-search-backend-module-techdocs": "^{{version '@backstage/plugin-search-backend-module-techdocs'}}",
"@backstage/plugin-search-backend-node": "^{{version '@backstage/plugin-search-backend-node'}}",
"@backstage/plugin-techdocs-backend": "^{{version '@backstage/plugin-techdocs-backend'}}",
"app": "link:../app",
- "better-sqlite3": "^8.0.0",
+ "better-sqlite3": "^9.0.0",
"dockerode": "^3.3.1",
"express": "^4.17.1",
"express-promise-router": "^4.1.0",
- "pg": "^8.3.0",
+ "node-gyp": "^9.0.0",
+ "pg": "^8.11.3",
"winston": "^3.2.1"
},
"devDependencies": {
diff --git a/packages/create-app/templates/default-app/packages/backend/src/plugins/catalog.ts b/packages/create-app/templates/default-app/packages/backend/src/plugins/catalog.ts
index 876cb6bccc..4decdca1c4 100644
--- a/packages/create-app/templates/default-app/packages/backend/src/plugins/catalog.ts
+++ b/packages/create-app/templates/default-app/packages/backend/src/plugins/catalog.ts
@@ -1,5 +1,5 @@
import { CatalogBuilder } from '@backstage/plugin-catalog-backend';
-import { ScaffolderEntitiesProcessor } from '@backstage/plugin-scaffolder-backend';
+import { ScaffolderEntitiesProcessor } from '@backstage/plugin-catalog-backend-module-scaffolder-entity-model';
import { Router } from 'express';
import { PluginEnvironment } from '../types';
diff --git a/packages/create-app/templates/default-app/packages/backend/src/plugins/search.ts.hbs b/packages/create-app/templates/default-app/packages/backend/src/plugins/search.ts.hbs
index e9469dcc1f..467ac60a5a 100644
--- a/packages/create-app/templates/default-app/packages/backend/src/plugins/search.ts.hbs
+++ b/packages/create-app/templates/default-app/packages/backend/src/plugins/search.ts.hbs
@@ -5,8 +5,8 @@ import {
LunrSearchEngine,
} from '@backstage/plugin-search-backend-node';
import { PluginEnvironment } from '../types';
-import { DefaultCatalogCollatorFactory } from '@backstage/plugin-catalog-backend';
-import { DefaultTechDocsCollatorFactory } from '@backstage/plugin-techdocs-backend';
+import { DefaultCatalogCollatorFactory } from '@backstage/plugin-search-backend-module-catalog';
+import { DefaultTechDocsCollatorFactory } from '@backstage/plugin-search-backend-module-techdocs';
import { Router } from 'express';
export default async function createPlugin(
diff --git a/packages/frontend-app-api/api-report.md b/packages/frontend-app-api/api-report.md
index 11c9ac03c5..3d6d936018 100644
--- a/packages/frontend-app-api/api-report.md
+++ b/packages/frontend-app-api/api-report.md
@@ -27,7 +27,7 @@ export type AppRouteBinder = <
) => void;
// @public (undocumented)
-export function createApp(options: {
+export function createApp(options?: {
features?: (BackstagePlugin | ExtensionOverrides)[];
configLoader?: () => Promise;
bindRoutes?(context: { bind: AppRouteBinder }): void;
diff --git a/packages/frontend-app-api/src/routing/extractRouteInfoFromAppNode.ts b/packages/frontend-app-api/src/routing/extractRouteInfoFromAppNode.ts
index 5700bf4eae..43955328a8 100644
--- a/packages/frontend-app-api/src/routing/extractRouteInfoFromAppNode.ts
+++ b/packages/frontend-app-api/src/routing/extractRouteInfoFromAppNode.ts
@@ -18,7 +18,7 @@ import { RouteRef, coreExtensionData } from '@backstage/frontend-plugin-api';
// eslint-disable-next-line @backstage/no-relative-monorepo-imports
import { toLegacyPlugin } from '../wiring/createApp';
import { BackstageRouteObject } from './types';
-import { AppNode } from '../tree';
+import { AppNode } from '@backstage/frontend-plugin-api';
// We always add a child that matches all subroutes but without any route refs. This makes
// sure that we're always able to match each route no matter how deep the navigation goes.
diff --git a/packages/frontend-app-api/src/tree/createAppTree.ts b/packages/frontend-app-api/src/tree/createAppTree.ts
index 2c36d56bf7..950669febd 100644
--- a/packages/frontend-app-api/src/tree/createAppTree.ts
+++ b/packages/frontend-app-api/src/tree/createAppTree.ts
@@ -22,7 +22,7 @@ import {
import { readAppExtensionsConfig } from './readAppExtensionsConfig';
import { resolveAppTree } from './resolveAppTree';
import { resolveAppNodeSpecs } from './resolveAppNodeSpecs';
-import { AppTree } from './types';
+import { AppTree } from '@backstage/frontend-plugin-api';
import { Config } from '@backstage/config';
import { instantiateAppNodeTree } from './instantiateAppNodeTree';
diff --git a/packages/frontend-app-api/src/tree/index.ts b/packages/frontend-app-api/src/tree/index.ts
index c864e86a7a..4b5ad5e867 100644
--- a/packages/frontend-app-api/src/tree/index.ts
+++ b/packages/frontend-app-api/src/tree/index.ts
@@ -14,10 +14,4 @@
* limitations under the License.
*/
-export type {
- AppNode,
- AppNodeEdges,
- AppNodeInstance,
- AppNodeSpec,
-} from './types';
export { createAppTree } from './createAppTree';
diff --git a/packages/frontend-app-api/src/tree/instantiateAppNodeTree.test.ts b/packages/frontend-app-api/src/tree/instantiateAppNodeTree.test.ts
index 2f4a112166..68a95fa1fe 100644
--- a/packages/frontend-app-api/src/tree/instantiateAppNodeTree.test.ts
+++ b/packages/frontend-app-api/src/tree/instantiateAppNodeTree.test.ts
@@ -25,7 +25,7 @@ import {
createAppNodeInstance,
instantiateAppNodeTree,
} from './instantiateAppNodeTree';
-import { AppNodeInstance, AppNodeSpec } from './types';
+import { AppNodeInstance, AppNodeSpec } from '@backstage/frontend-plugin-api';
import { resolveAppTree } from './resolveAppTree';
const testDataRef = createExtensionDataRef('test');
@@ -167,7 +167,8 @@ describe('instantiateAppNodeTree', () => {
{
...makeSpec(simpleExtension),
id: 'child-node',
- attachTo: { id: 'root-node', input: 'test' },
+ // Using an invalid input should not be an error when disabled
+ attachTo: { id: 'root-node', input: 'invalid' },
disabled: true,
},
]);
diff --git a/packages/frontend-app-api/src/tree/instantiateAppNodeTree.ts b/packages/frontend-app-api/src/tree/instantiateAppNodeTree.ts
index b6e4179867..003abbb97e 100644
--- a/packages/frontend-app-api/src/tree/instantiateAppNodeTree.ts
+++ b/packages/frontend-app-api/src/tree/instantiateAppNodeTree.ts
@@ -20,7 +20,11 @@ import {
ExtensionDataRef,
} from '@backstage/frontend-plugin-api';
import mapValues from 'lodash/mapValues';
-import { AppNode, AppNodeInstance, AppNodeSpec } from './types';
+import {
+ AppNode,
+ AppNodeInstance,
+ AppNodeSpec,
+} from '@backstage/frontend-plugin-api';
type Mutable = {
-readonly [P in keyof T]: T[P];
@@ -176,7 +180,9 @@ export function instantiateAppNodeTree(rootNode: AppNode): void {
}
return [{ id: child.spec.id, instance: childInstance }];
});
- instantiatedAttachments.set(input, instantiatedChildren);
+ if (instantiatedChildren.length > 0) {
+ instantiatedAttachments.set(input, instantiatedChildren);
+ }
}
(node as Mutable).instance = createAppNodeInstance({
diff --git a/packages/frontend-app-api/src/tree/resolveAppNodeSpecs.ts b/packages/frontend-app-api/src/tree/resolveAppNodeSpecs.ts
index b1a4760296..0a024c0a3f 100644
--- a/packages/frontend-app-api/src/tree/resolveAppNodeSpecs.ts
+++ b/packages/frontend-app-api/src/tree/resolveAppNodeSpecs.ts
@@ -22,7 +22,7 @@ import {
// eslint-disable-next-line @backstage/no-relative-monorepo-imports
import { toInternalExtensionOverrides } from '../../../frontend-plugin-api/src/wiring/createExtensionOverrides';
import { ExtensionParameters } from './readAppExtensionsConfig';
-import { AppNodeSpec } from './types';
+import { AppNodeSpec } from '@backstage/frontend-plugin-api';
/** @internal */
export function resolveAppNodeSpecs(options: {
diff --git a/packages/frontend-app-api/src/tree/resolveAppTree.ts b/packages/frontend-app-api/src/tree/resolveAppTree.ts
index e1665a01fd..24948373bf 100644
--- a/packages/frontend-app-api/src/tree/resolveAppTree.ts
+++ b/packages/frontend-app-api/src/tree/resolveAppTree.ts
@@ -14,7 +14,12 @@
* limitations under the License.
*/
-import { AppTree, AppNode, AppNodeInstance, AppNodeSpec } from './types';
+import {
+ AppTree,
+ AppNode,
+ AppNodeInstance,
+ AppNodeSpec,
+} from '@backstage/frontend-plugin-api';
function indent(str: string) {
return str.replace(/^/gm, ' ');
diff --git a/packages/frontend-app-api/src/wiring/createApp.test.tsx b/packages/frontend-app-api/src/wiring/createApp.test.tsx
index e9fb48f957..80d9f846f0 100644
--- a/packages/frontend-app-api/src/wiring/createApp.test.tsx
+++ b/packages/frontend-app-api/src/wiring/createApp.test.tsx
@@ -15,6 +15,8 @@
*/
import {
+ AppTreeApi,
+ appTreeApiRef,
createPageExtension,
createPlugin,
createThemeExtension,
@@ -23,6 +25,7 @@ import { screen, waitFor } from '@testing-library/react';
import { createApp } from './createApp';
import { MockConfigApi, renderWithEffects } from '@backstage/test-utils';
import React from 'react';
+import { useApi } from '@backstage/core-plugin-api';
describe('createApp', () => {
it('should allow themes to be installed', async () => {
@@ -90,4 +93,58 @@ describe('createApp', () => {
expect(screen.getByText('Last Page')).toBeInTheDocument(),
);
});
+
+ it('should make the app structure available through the AppTreeApi', async () => {
+ let appTreeApi: AppTreeApi | undefined = undefined;
+
+ const app = createApp({
+ configLoader: async () => new MockConfigApi({}),
+ features: [
+ createPlugin({
+ id: 'my-plugin',
+ extensions: [
+ createPageExtension({
+ id: 'plugin.my-plugin.page',
+ defaultPath: '/',
+ loader: async () => {
+ const Component = () => {
+ appTreeApi = useApi(appTreeApiRef);
+ return
My Plugin Page
;
+ };
+ return ;
+ },
+ }),
+ ],
+ }),
+ ],
+ });
+
+ await renderWithEffects(app.createRoot());
+
+ expect(appTreeApi).toBeDefined();
+ const { tree } = appTreeApi!.getTree();
+
+ expect(String(tree.root)).toMatchInlineSnapshot(`
+ "
+ root [
+
+ content [
+
+ routes [
+
+ ]
+
+ ]
+ nav [
+
+ ]
+
+ ]
+ themes [
+
+
+ ]
+ "
+ `);
+ });
});
diff --git a/packages/frontend-app-api/src/wiring/createApp.tsx b/packages/frontend-app-api/src/wiring/createApp.tsx
index d726773fd3..ca0e1d60d1 100644
--- a/packages/frontend-app-api/src/wiring/createApp.tsx
+++ b/packages/frontend-app-api/src/wiring/createApp.tsx
@@ -17,6 +17,8 @@
import React, { JSX } from 'react';
import { ConfigReader, Config } from '@backstage/config';
import {
+ AppTree,
+ appTreeApiRef,
BackstagePlugin,
coreExtensionData,
ExtensionDataRef,
@@ -87,7 +89,8 @@ import { AppRouteBinder } from '../routing';
import { RoutingProvider } from '../routing/RoutingProvider';
import { resolveRouteBindings } from '../routing/resolveRouteBindings';
import { collectRouteIds } from '../routing/collectRouteIds';
-import { AppNode, createAppTree } from '../tree';
+import { createAppTree } from '../tree';
+import { AppNode } from '@backstage/frontend-plugin-api';
const builtinExtensions = [
Core,
@@ -222,7 +225,7 @@ function deduplicateFeatures(
}
/** @public */
-export function createApp(options: {
+export function createApp(options?: {
features?: (BackstagePlugin | ExtensionOverrides)[];
configLoader?: () => Promise;
bindRoutes?(context: { bind: AppRouteBinder }): void;
@@ -240,11 +243,11 @@ export function createApp(options: {
);
const discoveredFeatures = getAvailableFeatures(config);
- const loadedFeatures = (await options.featureLoader?.({ config })) ?? [];
+ const loadedFeatures = (await options?.featureLoader?.({ config })) ?? [];
const allFeatures = deduplicateFeatures([
...discoveredFeatures,
...loadedFeatures,
- ...(options.features ?? []),
+ ...(options?.features ?? []),
]);
const tree = createAppTree({
@@ -262,13 +265,13 @@ export function createApp(options: {
const routeIds = collectRouteIds(allFeatures);
const App = () => (
-
+ e.instance?.getData(coreExtensionData.apiFactory))
.filter((x): x is AnyApiFactory => !!x) ?? [];
const themeExtensions =
- core.edges.attachments
+ tree.root.edges.attachments
.get('themes')
?.map(e => e.instance?.getData(coreExtensionData.theme))
.filter((x): x is AppTheme => !!x) ?? [];
@@ -414,6 +417,14 @@ function createApiHolder(core: AppNode, configApi: ConfigApi): ApiHolder {
},
});
+ factoryRegistry.register('static', {
+ api: appTreeApiRef,
+ deps: {},
+ factory: () => ({
+ getTree: () => ({ tree }),
+ }),
+ });
+
factoryRegistry.register('static', {
api: appThemeApiRef,
deps: {},
diff --git a/packages/frontend-plugin-api/api-report.md b/packages/frontend-plugin-api/api-report.md
index 250ce5f676..794da9617b 100644
--- a/packages/frontend-plugin-api/api-report.md
+++ b/packages/frontend-plugin-api/api-report.md
@@ -7,6 +7,7 @@
import { AnyApiFactory } from '@backstage/core-plugin-api';
import { AnyApiRef } from '@backstage/core-plugin-api';
+import { ApiRef } from '@backstage/core-plugin-api';
import { AppTheme } from '@backstage/core-plugin-api';
import { IconComponent } from '@backstage/core-plugin-api';
import { JsonObject } from '@backstage/types';
@@ -55,6 +56,66 @@ export type AnyRoutes = {
[name in string]: RouteRef;
};
+// @public
+export interface AppNode {
+ readonly edges: AppNodeEdges;
+ readonly instance?: AppNodeInstance;
+ readonly spec: AppNodeSpec;
+}
+
+// @public
+export interface AppNodeEdges {
+ // (undocumented)
+ readonly attachedTo?: {
+ node: AppNode;
+ input: string;
+ };
+ // (undocumented)
+ readonly attachments: ReadonlyMap;
+}
+
+// @public
+export interface AppNodeInstance {
+ getData(ref: ExtensionDataRef): T | undefined;
+ getDataRefs(): Iterable>;
+}
+
+// @public
+export interface AppNodeSpec {
+ // (undocumented)
+ readonly attachTo: {
+ id: string;
+ input: string;
+ };
+ // (undocumented)
+ readonly config?: unknown;
+ // (undocumented)
+ readonly disabled: boolean;
+ // (undocumented)
+ readonly extension: Extension;
+ // (undocumented)
+ readonly id: string;
+ // (undocumented)
+ readonly source?: BackstagePlugin;
+}
+
+// @public
+export interface AppTree {
+ readonly nodes: ReadonlyMap;
+ readonly orphans: Iterable;
+ readonly root: AppNode;
+}
+
+// @public
+export interface AppTreeApi {
+ getTree(): {
+ tree: AppTree;
+ };
+}
+
+// @public
+export const appTreeApiRef: ApiRef;
+
// @public (undocumented)
export interface BackstagePlugin<
Routes extends AnyRoutes = AnyRoutes,
diff --git a/packages/frontend-plugin-api/src/apis/definitions/index.ts b/packages/frontend-plugin-api/src/apis/definitions/index.ts
new file mode 100644
index 0000000000..8facdca2ca
--- /dev/null
+++ b/packages/frontend-plugin-api/src/apis/definitions/index.ts
@@ -0,0 +1,25 @@
+/*
+ * Copyright 2023 The Backstage Authors
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+export {
+ appTreeApiRef,
+ type AppNode,
+ type AppNodeEdges,
+ type AppNodeInstance,
+ type AppNodeSpec,
+ type AppTree,
+ type AppTreeApi,
+} from './AppTreeApi';
diff --git a/packages/frontend-plugin-api/src/apis/index.ts b/packages/frontend-plugin-api/src/apis/index.ts
new file mode 100644
index 0000000000..5a012c0553
--- /dev/null
+++ b/packages/frontend-plugin-api/src/apis/index.ts
@@ -0,0 +1,17 @@
+/*
+ * Copyright 2023 The Backstage Authors
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+export * from './definitions';
diff --git a/packages/frontend-plugin-api/src/index.ts b/packages/frontend-plugin-api/src/index.ts
index 73abf28ce4..498bc96a77 100644
--- a/packages/frontend-plugin-api/src/index.ts
+++ b/packages/frontend-plugin-api/src/index.ts
@@ -20,6 +20,7 @@
* @packageDocumentation
*/
+export * from './apis';
export * from './components';
export * from './extensions';
export * from './routing';
diff --git a/plugins/app-backend/package.json b/plugins/app-backend/package.json
index e8230f715e..4d5de74edb 100644
--- a/plugins/app-backend/package.json
+++ b/plugins/app-backend/package.json
@@ -57,7 +57,7 @@
"fs-extra": "10.1.0",
"globby": "^11.0.0",
"helmet": "^6.0.0",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"lodash": "^4.17.21",
"luxon": "^3.0.0",
"winston": "^3.2.1",
diff --git a/plugins/auth-backend/package.json b/plugins/auth-backend/package.json
index b52560cbb9..52a4d262f7 100644
--- a/plugins/auth-backend/package.json
+++ b/plugins/auth-backend/package.json
@@ -51,7 +51,7 @@
"@types/express": "^4.17.6",
"@types/passport": "^1.0.3",
"compression": "^1.7.4",
- "connect-session-knex": "^3.0.1",
+ "connect-session-knex": "^4.0.0",
"cookie-parser": "^1.4.5",
"cors": "^2.8.5",
"express": "^4.17.1",
@@ -61,7 +61,7 @@
"google-auth-library": "^8.0.0",
"jose": "^4.6.0",
"jwt-decode": "^3.1.0",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"lodash": "^4.17.21",
"luxon": "^3.0.0",
"minimatch": "^5.0.0",
diff --git a/plugins/badges-backend/package.json b/plugins/badges-backend/package.json
index fee41b8e7f..21df60acb2 100644
--- a/plugins/badges-backend/package.json
+++ b/plugins/badges-backend/package.json
@@ -45,7 +45,7 @@
"cors": "^2.8.5",
"express": "^4.17.1",
"express-promise-router": "^4.1.0",
- "knex": "^2.4.2",
+ "knex": "^3.0.0",
"lodash": "^4.17.21",
"supertest": "^6.3.3",
"uuid": "^9.0.0",
diff --git a/plugins/bazaar-backend/package.json b/plugins/bazaar-backend/package.json
index 28489be39f..02ca87224b 100644
--- a/plugins/bazaar-backend/package.json
+++ b/plugins/bazaar-backend/package.json
@@ -49,7 +49,7 @@
"@types/express": "^4.17.6",
"express": "^4.17.1",
"express-promise-router": "^4.1.0",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"winston": "^3.2.1",
"yn": "^4.0.0"
},
diff --git a/plugins/bazaar/README.md b/plugins/bazaar/README.md
index 9b5fb466df..941979d4d3 100644
--- a/plugins/bazaar/README.md
+++ b/plugins/bazaar/README.md
@@ -2,15 +2,15 @@
### What is the Bazaar?
-The Bazaar is a place where teams can propose projects for cross-functional team development. Essentially a marketplace for internal projects suitable for [Inner Sourcing](https://en.wikipedia.org/wiki/Inner_source). With "Inner Sourcing", we mean projects that are developed internally within a company, but with Open Source best practices.
+The Bazaar is a place where teams can propose projects for cross-functional team development. Essentially, itâs a marketplace for internal projects suitable for [Inner Sourcing](https://en.wikipedia.org/wiki/Inner_source). By âInner Sourcing,â we mean projects that are developed internally within a company but follow Open Source best practices.
### Why?
-Many companies today are of high need to increase the ease of cross-team cooperation. In large organizations, engineers often have limited ways of discovering or announcing the projects which could benefit from a wider development effort in terms of different expertise, experiences, and teams spread across the organization. With no good way to find these existing internal projects to join, the possibility of working with Inner Sourcing practices suffers.
+Many companies today have a high need to increase the ease of cross-team cooperation. In large organizations, engineers often have limited ways of discovering or announcing projects that could benefit from a wider development effort in terms of different expertise, experiences, and teams spread across the organization. With no good way to find these existing internal projects to join, the possibility of working with Inner Sourcing practices suffers.
### How?
-The Bazaar allows engineers and teams to open up and announce their new and exciting projects for transparent cooperation in other parts of larger organizations. The Bazaar ensures that new Inner Sourcing friendly projects gain visibility through Backstage and a way for interested engineers to show their interest and in the future contribute with their specific skill set. The Bazaar also provides an easy way to manage, catalog, and browse these Inner Sourcing friendly projects and components.
+The Bazaar allows engineers and teams to open up and announce their new and exciting projects for transparent cooperation in other parts of larger organizations. The Bazaar ensures that new Inner Sourcing-friendly projects gain visibility through Backstage and a way for interested engineers to show their interest and, in the future, contribute with their specific skill set. The Bazaar also provides an easy way to manage, catalog, and browse these Inner Sourcing-friendly projects and components.
# Note
diff --git a/plugins/catalog-backend-module-gitlab/src/lib/client.ts b/plugins/catalog-backend-module-gitlab/src/lib/client.ts
index c4cdd444cb..65c3898d06 100644
--- a/plugins/catalog-backend-module-gitlab/src/lib/client.ts
+++ b/plugins/catalog-backend-module-gitlab/src/lib/client.ts
@@ -92,7 +92,7 @@ export class GitLabClient {
options?: CommonListOptions,
): Promise> {
return this.pagedRequest(
- `/groups/${encodeURIComponent(groupPath)}/members`,
+ `/groups/${encodeURIComponent(groupPath)}/members/all`,
{
...options,
show_seat_info: true,
diff --git a/plugins/catalog-backend-module-gitlab/src/providers/GitlabOrgDiscoveryEntityProvider.test.ts b/plugins/catalog-backend-module-gitlab/src/providers/GitlabOrgDiscoveryEntityProvider.test.ts
index ad930ea23d..669abc69b6 100644
--- a/plugins/catalog-backend-module-gitlab/src/providers/GitlabOrgDiscoveryEntityProvider.test.ts
+++ b/plugins/catalog-backend-module-gitlab/src/providers/GitlabOrgDiscoveryEntityProvider.test.ts
@@ -569,7 +569,7 @@ describe('GitlabOrgDiscoveryEntityProvider', () => {
),
),
rest.get(
- `https://gitlab.com/api/v4/groups/group1/members`,
+ `https://gitlab.com/api/v4/groups/group1/members/all`,
(_req, res, ctx) => {
const response = [
{
diff --git a/plugins/catalog-backend-module-incremental-ingestion/package.json b/plugins/catalog-backend-module-incremental-ingestion/package.json
index 5eb327b812..abe3de740e 100644
--- a/plugins/catalog-backend-module-incremental-ingestion/package.json
+++ b/plugins/catalog-backend-module-incremental-ingestion/package.json
@@ -59,7 +59,7 @@
"@types/luxon": "^3.0.0",
"express": "^4.17.1",
"express-promise-router": "^4.1.0",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"luxon": "^3.0.0",
"uuid": "^8.3.2",
"winston": "^3.2.1"
diff --git a/plugins/catalog-backend-module-msgraph/api-report.md b/plugins/catalog-backend-module-msgraph/api-report.md
index 3e4d8d99bc..7f5c4b804c 100644
--- a/plugins/catalog-backend-module-msgraph/api-report.md
+++ b/plugins/catalog-backend-module-msgraph/api-report.md
@@ -261,6 +261,17 @@ export function readMicrosoftGraphOrg(
groups: GroupEntity[];
}>;
+// @public
+export function readProviderConfig(
+ id: string,
+ config: Config,
+): MicrosoftGraphProviderConfig;
+
+// @public
+export function readProviderConfigs(
+ config: Config,
+): MicrosoftGraphProviderConfig[];
+
// @public
export type UserTransformer = (
user: MicrosoftGraph.User,
diff --git a/plugins/catalog-backend-module-msgraph/src/microsoftGraph/config.ts b/plugins/catalog-backend-module-msgraph/src/microsoftGraph/config.ts
index cf4ec646a2..1d9592e96f 100644
--- a/plugins/catalog-backend-module-msgraph/src/microsoftGraph/config.ts
+++ b/plugins/catalog-backend-module-msgraph/src/microsoftGraph/config.ts
@@ -226,6 +226,13 @@ export function readMicrosoftGraphConfig(
return providers;
}
+/**
+ * Parses all configured providers.
+ *
+ * @param config - The root of the msgraph config hierarchy
+ *
+ * @public
+ */
export function readProviderConfigs(
config: Config,
): MicrosoftGraphProviderConfig[] {
@@ -248,6 +255,14 @@ export function readProviderConfigs(
});
}
+/**
+ * Parses a single configured provider by id.
+ *
+ * @param id - the id of the provider to parse
+ * @param config - The root of the msgraph config hierarchy
+ *
+ * @public
+ */
export function readProviderConfig(
id: string,
config: Config,
diff --git a/plugins/catalog-backend-module-msgraph/src/microsoftGraph/index.ts b/plugins/catalog-backend-module-msgraph/src/microsoftGraph/index.ts
index 37dcffec22..4db3fb69c6 100644
--- a/plugins/catalog-backend-module-msgraph/src/microsoftGraph/index.ts
+++ b/plugins/catalog-backend-module-msgraph/src/microsoftGraph/index.ts
@@ -16,7 +16,11 @@
export { MicrosoftGraphClient } from './client';
export type { GroupMember, ODataQuery } from './client';
-export { readMicrosoftGraphConfig } from './config';
+export {
+ readMicrosoftGraphConfig,
+ readProviderConfigs,
+ readProviderConfig,
+} from './config';
export type { MicrosoftGraphProviderConfig } from './config';
export {
MICROSOFT_EMAIL_ANNOTATION,
diff --git a/plugins/catalog-backend-module-unprocessed/package.json b/plugins/catalog-backend-module-unprocessed/package.json
index 03f3471b28..e04ce27b51 100644
--- a/plugins/catalog-backend-module-unprocessed/package.json
+++ b/plugins/catalog-backend-module-unprocessed/package.json
@@ -38,6 +38,6 @@
"@backstage/catalog-model": "workspace:^",
"@backstage/plugin-auth-node": "workspace:^",
"express-promise-router": "^4.1.1",
- "knex": "^2.4.2"
+ "knex": "^3.0.0"
}
}
diff --git a/plugins/catalog-backend/package.json b/plugins/catalog-backend/package.json
index a6f266af48..510312cc4c 100644
--- a/plugins/catalog-backend/package.json
+++ b/plugins/catalog-backend/package.json
@@ -71,7 +71,7 @@
"fs-extra": "10.1.0",
"git-url-parse": "^13.0.0",
"glob": "^7.1.6",
- "knex": "^2.0.0",
+ "knex": "^3.0.0",
"lodash": "^4.17.21",
"luxon": "^3.0.0",
"minimatch": "^5.0.0",
@@ -93,7 +93,7 @@
"@types/lodash": "^4.14.151",
"@types/supertest": "^2.0.8",
"@types/uuid": "^8.0.0",
- "better-sqlite3": "^8.0.0",
+ "better-sqlite3": "^9.0.0",
"luxon": "^3.0.0",
"msw": "^1.0.0",
"supertest": "^6.1.3",
diff --git a/plugins/catalog-react/api-report.md b/plugins/catalog-react/api-report.md
index 03c97ee4c4..5ebc9de8d6 100644
--- a/plugins/catalog-react/api-report.md
+++ b/plugins/catalog-react/api-report.md
@@ -22,7 +22,7 @@ import { PropsWithChildren } from 'react';
import { default as React_2 } from 'react';
import { ReactNode } from 'react';
import { RouteRef } from '@backstage/core-plugin-api';
-import { ScmIntegrationRegistry } from '@backstage/integration';
+import { scmIntegrationsApiRef } from '@backstage/integration-react';
import { StyleRules } from '@material-ui/core/styles/withStyles';
import { SystemEntity } from '@backstage/catalog-model';
import { TableColumn } from '@backstage/core-components';
@@ -597,7 +597,7 @@ export function getEntityRelations(
// @public (undocumented)
export function getEntitySourceLocation(
entity: Entity,
- scmIntegrationsApi: ScmIntegrationRegistry,
+ scmIntegrationsApi: typeof scmIntegrationsApiRef.T,
): EntitySourceLocation | undefined;
// @public (undocumented)
diff --git a/plugins/catalog-react/package.json b/plugins/catalog-react/package.json
index 25bd244ab7..3c39185732 100644
--- a/plugins/catalog-react/package.json
+++ b/plugins/catalog-react/package.json
@@ -52,7 +52,7 @@
"@backstage/core-plugin-api": "workspace:^",
"@backstage/errors": "workspace:^",
"@backstage/frontend-plugin-api": "workspace:^",
- "@backstage/integration": "workspace:^",
+ "@backstage/integration-react": "workspace:^",
"@backstage/plugin-catalog-common": "workspace:^",
"@backstage/plugin-permission-common": "workspace:^",
"@backstage/plugin-permission-react": "workspace:^",
diff --git a/plugins/catalog-react/src/utils/getEntitySourceLocation.ts b/plugins/catalog-react/src/utils/getEntitySourceLocation.ts
index d2141449a8..40074b79e2 100644
--- a/plugins/catalog-react/src/utils/getEntitySourceLocation.ts
+++ b/plugins/catalog-react/src/utils/getEntitySourceLocation.ts
@@ -19,7 +19,7 @@ import {
Entity,
parseLocationRef,
} from '@backstage/catalog-model';
-import { ScmIntegrationRegistry } from '@backstage/integration';
+import { scmIntegrationsApiRef } from '@backstage/integration-react';
/** @public */
export type EntitySourceLocation = {
@@ -30,7 +30,7 @@ export type EntitySourceLocation = {
/** @public */
export function getEntitySourceLocation(
entity: Entity,
- scmIntegrationsApi: ScmIntegrationRegistry,
+ scmIntegrationsApi: typeof scmIntegrationsApiRef.T,
): EntitySourceLocation | undefined {
const sourceLocation =
entity.metadata.annotations?.[ANNOTATION_SOURCE_LOCATION];
diff --git a/plugins/catalog/src/components/EntityLayout/EntityLayout.test.tsx b/plugins/catalog/src/components/EntityLayout/EntityLayout.test.tsx
index 33414152be..3634405af8 100644
--- a/plugins/catalog/src/components/EntityLayout/EntityLayout.test.tsx
+++ b/plugins/catalog/src/components/EntityLayout/EntityLayout.test.tsx
@@ -233,4 +233,35 @@ describe('EntityLayout', () => {
expect(screen.queryByText('tabbed-test-title-2')).not.toBeInTheDocument();
expect(screen.getByText('tabbed-test-title-3')).toBeInTheDocument();
});
+
+ it('renders the owner links inside `p` tags', async () => {
+ const mockTargetRef = 'my:target/ref';
+ const ownerEntity = {
+ ...mockEntity,
+ relations: [{ type: 'ownedBy', targetRef: mockTargetRef }],
+ };
+ await renderInTestApp(
+
+
+
+
+
diff --git a/packages/frontend-app-api/src/tree/types.ts b/packages/frontend-plugin-api/src/apis/definitions/AppTreeApi.ts
similarity index 72%
rename from packages/frontend-app-api/src/tree/types.ts
rename to packages/frontend-plugin-api/src/apis/definitions/AppTreeApi.ts
index 3246dfe5c2..6c79a16964 100644
--- a/packages/frontend-app-api/src/tree/types.ts
+++ b/packages/frontend-plugin-api/src/apis/definitions/AppTreeApi.ts
@@ -14,20 +14,13 @@
* limitations under the License.
*/
-import {
- BackstagePlugin,
- Extension,
- ExtensionDataRef,
-} from '@backstage/frontend-plugin-api';
-
-/*
-NOTE: These types are marked as @internal for now, but the intention is for this to be a public API in the future.
-*/
+import { createApiRef } from '@backstage/core-plugin-api';
+import { BackstagePlugin, Extension, ExtensionDataRef } from '../../wiring';
/**
* The specification for this node in the app tree.
*
- * @internal
+ * @public
* @remarks
*
* The specifications for a collection of app nodes is all the information needed
@@ -43,9 +36,9 @@ export interface AppNodeSpec {
}
/**
- * The connections from this node to other nodes.
+ * The connections from this {@link AppNode} to other nodes.
*
- * @internal
+ * @public
* @remarks
*
* The app node edges are resolved based on the app node specs, regardless of whether
@@ -57,9 +50,9 @@ export interface AppNodeEdges {
}
/**
* The instance of this node in the app tree.
*
- * @internal
+ * @public
* @remarks
*
* The app node instance is created when the `factory` function of an extension is called.
@@ -74,8 +67,9 @@ export interface AppNodeInstance {
}
/**
+ * A node in the {@link AppTree}.
*
- * @internal
+ * @public
*/
export interface AppNode {
/** The specification for how this node should be instantiated */
@@ -87,15 +81,34 @@ export interface AppNode {
}
/**
- * The app tree containing all nodes of the app.
+ * The app tree containing all {@link AppNode}s of the app.
*
- * @internal
+ * @public
*/
export interface AppTree {
/** The root node of the app */
- root: AppNode;
+ readonly root: AppNode;
/** A map of all nodes in the app by ID, including orphaned or disabled nodes */
- nodes: ReadonlyMap;
+ readonly nodes: ReadonlyMap;
/** A sequence of all nodes with a parent that is not reachable from the app root node */
- orphans: Iterable;
+ readonly orphans: Iterable;
}
+
+/**
+ * The API for interacting with the {@link AppTree}.
+ *
+ * @public
+ */
+export interface AppTreeApi {
+ /**
+ * Get the {@link AppTree} for the app.
+ */
+ getTree(): { tree: AppTree };
+}
+
+/**
+ * The `ApiRef` of {@link AppTreeApi}.
+ *
+ * @public
+ */
+export const appTreeApiRef = createApiRef({ id: 'core.app-tree' });
@@ -14,20 +14,13 @@
/**
- * The specification for this node in the app tree.
+ * The specification for this {@link AppNode} in the {@link AppTree}.
*
@@ -57,9 +50,9 @@ export interface AppNodeEdges {
}
/**
- * The instance of this node in the app tree.
+ * The instance of this {@link AppNode} in the {@link AppTree}.
*